==> fastapi-view-mixins-0.0.4.tar.gz: fastapi-view-mixins-0.0.4/fastapi_views/views/mixins.py <==
from typing import Type, Any, TypeVar, Union

from sqlalchemy import select
from sqlalchemy.sql import Select

from fastapi_views.pagination.core import PaginationBase
from .async_api import Table, BaseAsyncAPI
from .base import BaseAPI
from .sync_api import BaseSyncAPI

API_CLS = TypeVar('API_CLS', bound=BaseAPI)


class BaseAPIMixin:
    """Base API mixin."""

    model: Type[Table] = None
    """A SQLAlchemy model class."""
    pk_field: Union[str, None] = None
    """Unique field like model id."""
    paginate_by: Union[int, None] = None
    """Page objects limit."""
    pagination_strategy: Union[Type[PaginationBase], None] = None
    """PaginationCursor / PaginationLimitOffset, default set to limit offset."""
    async_api: bool = False
    """When set to True then will be used async repository."""

    @property
    def _get_api_cls(self) -> Type[API_CLS]:
        """Get repository API cls."""
        return BaseSyncAPI[self.model] if not self.async_api else BaseAsyncAPI[self.model]

    def __init__(self, *args, **kwargs) -> None:
        attrs = kwargs.pop('attrs', {})
        self.args = args
        self.kwargs = kwargs

        for key, value in attrs.items():
            if hasattr(self, key):
                setattr(self, key, value)
            else:
                raise AttributeError(f'{key} is not a valid attribute')

        if not isinstance(self.async_api, bool):
            raise TypeError(f'{self.async_api} expected to be boolean value.')

        self.api_view = self._get_api_cls(
            model=self.model,
            pk_field=self.pk_field,
            paginate_by=self.paginate_by,
            pagination_strategy=self.pagination_strategy,
        )

        # assigned after, so we can reference to api_view in both of the methods if needed
        self.api_view.pagination_kwargs = self.get_pagination_kwargs()
        self.api_view.statement = self.get_statement()

    def get_statement(self) -> Select:
        """Return sqlalchemy orm statement."""

    def get_pagination_kwargs(self) -> dict[str, Any]:
        """Return pagination kwargs"""


class BaseAPIListMixin(BaseAPIMixin):
    """Retrieve object list mixin."""

    pk_field = None

    def get_all(self, *args, **kwargs):
        return self.api_view.get_all(*args, **kwargs)

    def get_all_with_pagination(self, *args, **kwargs):
        return self.api_view.get_all_with_pagination(*args, **kwargs)

    def get_statement(self) -> Select:
        return select(self.model)

    def get_pagination_kwargs(self) -> dict[str, Any]:
        return {
            'model': self.model,
            'ordering': ['id'],
            'cursor_prefixes': ['next__', 'prev__']
        }


class BaseAPIDetailMixin(BaseAPIMixin):
    """Retrieve object mixin."""

    pk_field = 'id'

    def get_detail(self, *args, **kwargs):
        return self.api_view.get_detail(*args, **kwargs)


class BaseAPIUpdateMixin(BaseAPIMixin):
    """Update objects mixin."""

    pk_field = 'id'

    def update_single(self, *args, **kwargs):
        return self.api_view.update_single(*args, **kwargs)


class BaseAPICreateMixin(BaseAPIMixin):
    """Post objects mixin."""
    pk_field = None

    def create(self, *args, **kwargs):
        return self.api_view.create(*args, **kwargs)


class BaseAPIDestroyMixin(BaseAPIMixin):
    """Delete objects mixin."""

    pk_field = 'id'

    def delete(self, *args, **kwargs):
        return self.api_view.delete(*args, **kwargs)

==> fastapi-view-mixins-0.1.1.tar.gz: fastapi-view-mixins-0.1.1/fastapi_views/views/mixins.py <==
import abc
from typing import Any, Type, TypeVar, Union

from ..pagination.core import PaginationBase
from .core import BaseRepositoryView

API_CLS = TypeVar('API_CLS', bound=BaseRepositoryView)


class BaseAPIMixin:
    """Base API mixin."""

    paginate_by: Union[int, None] = None
    """Page objects limit."""
    pagination_strategy: Union[Type[PaginationBase], None] = None
    """As default set to limit offset."""
    model: Any = None

    def __init__(self, *args, **kwargs) -> None:
        attrs = kwargs.pop('attrs', {})
        self.args = args
        self.kwargs = kwargs
        self._api = None

        for key, value in attrs.items():
            if hasattr(self, key):
                setattr(self, key, value)
            else:
                raise AttributeError(f'{key} is not a valid attribute')

    @property
    def api_view(self) -> API_CLS:
        return self._api

    @api_view.setter
    def api_view(self, value):
        if not isinstance(value, BaseRepositoryView):
            raise TypeError('Invalid type of api_view.')
        self._api = value

    def get_pagination_kwargs(self) -> dict[str, Any]:
        """
        Return pagination kwargs.
        Used only in cursor pagination.
        """


class AbstractAPIMixin(BaseAPIMixin, abc.ABC):

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        self.api_view = self._get_repository()

    @abc.abstractmethod
    def _get_repository(self) -> API_CLS:
        """Get repository API cls."""


class BaseAPIListMixin(BaseAPIMixin):
    """Retrieve object list mixin."""

    def get_all(self, *args, **kwargs):
        return self.api_view.get_all(*args, **kwargs)

    def get_all_with_pagination(self, *args, **kwargs):
        return self.api_view.get_all_with_pagination(*args, **kwargs)

    def get_pagination_kwargs(self) -> dict[str, Any]:
        return {
            'model': self.model,
            'ordering': [],
            'cursor_prefixes': ['next__', 'prev__']
        }


class BaseAPIDetailMixin(BaseAPIMixin):
    """Retrieve object mixin."""

    def get_detail(self, *args, **kwargs):
        return self.api_view.get_detail(*args, **kwargs)


class BaseAPIUpdateMixin(BaseAPIMixin):
    """Update objects mixin."""

    def update_one(self, *args, **kwargs):
        return self.api_view.update_one(*args, **kwargs)


class BaseAPICreateMixin(BaseAPIMixin):
    """Post objects mixin."""

    def create(self, *args, **kwargs):
        return self.api_view.create(*args, **kwargs)


class BaseAPIDestroyMixin(BaseAPIMixin):
    """Delete objects mixin."""

    def delete(self, *args, **kwargs):
        return self.api_view.delete(*args, **kwargs)
